@@ -37,15 +37,26 @@ pub enum Literal {
         export_name: String,
         fields: HashMap<String, Literal>,
     },
+    Cast {
+        ty: Type,
+        value: Box<Literal>,
+    },
 }
 
 impl Literal {
     fn replace_self_with(&mut self, self_ty: &Path) {
         match *self {
-            Literal::PostfixUnaryOp { .. }
-            | Literal::BinOp { .. }
-            | Literal::Expr(..)
-            | Literal::Path(..) => {}
+            Literal::PostfixUnaryOp { ref mut value, .. } => {
+                value.replace_self_with(self_ty);
+            }
+            Literal::BinOp {
+                ref mut left,
+                ref mut right,
+                ..
+            } => {
+                left.replace_self_with(self_ty);
+                right.replace_self_with(self_ty);
+            }
             Literal::Struct {
                 ref mut path,
                 ref mut export_name,
@@ -58,6 +69,14 @@ impl Literal {
                     expr.replace_self_with(self_ty);
                 }
             }
+            Literal::Cast {
+                ref mut ty,
+                ref mut value,
+            } => {
+                ty.replace_self_with(self_ty);
+                value.replace_self_with(self_ty);
+            }
+            Literal::Expr(..) | Literal::Path(..) => {}
         }
     }
 
@@ -72,6 +91,24 @@ impl Literal {
                 ..
             } => left.is_valid(bindings) && right.is_valid(bindings),
             Literal::Struct { ref path, .. } => bindings.struct_exists(path),
+            Literal::Cast { ref value, .. } => value.is_valid(bindings),
+        }
+    }
+
+    pub fn uses_only_primitive_types(&self) -> bool {
+        match self {
+            Literal::Expr(..) => true,
+            Literal::Path(..) => true,
+            Literal::PostfixUnaryOp { ref value, .. } => value.uses_only_primitive_types(),
+            Literal::BinOp {
+                ref left,
+                ref right,
+                ..
+            } => left.uses_only_primitive_types() & right.uses_only_primitive_types(),
+            Literal::Struct { .. } => false,
+            Literal::Cast { ref value, ref ty } => {
+                value.uses_only_primitive_types() && ty.is_primitive_or_ptr_primitive()
+            }
         }
     }
 }
@@ -104,6 +141,13 @@ impl Literal {
                 right.rename_for_config(config);
             }
             Literal::Expr(_) => {}
+            Literal::Cast {
+                ref mut ty,
+                ref mut value,
+            } => {
+                ty.rename_for_config(config, &GenericParams::default());
+                value.rename_for_config(config);
+            }
         }
     }
 
@@ -229,6 +273,19 @@ impl Literal {
 
             syn::Expr::Paren(syn::ExprParen { ref expr, .. }) => Self::load(expr),
 
+            syn::Expr::Cast(syn::ExprCast {
+                ref expr, ref ty, ..
+            }) => {
+                let val = Self::load(expr)?;
+                match Type::load(ty)? {
+                    Some(ty) => Ok(Literal::Cast {
+                        ty,
+                        value: Box::new(val),
+                    }),
+                    None => Err("Cannot cast to zero sized type.".to_owned()),
+                }
+            }
+
             _ => Err(format!("Unsupported expression. {:?}", *expr)),
         }
     }
@@ -252,6 +309,12 @@ impl Literal {
                 right.write(config, out);
                 write!(out, ")");
             }
+            Literal::Cast { ref ty, ref value } => {
+                write!(out, "(");
+                ty.write(config, out);
+                write!(out, ")");
+                value.write(config, out);
+            }
             Literal::Struct {
                 export_name,
                 fields,
@@ -370,6 +433,10 @@ impl Constant {
             associated_to,
         }
     }
+
+    pub fn uses_only_primitive_types(&self) -> bool {
+        self.value.uses_only_primitive_types() && self.ty.is_primitive_or_ptr_primitive()
+    }
 }
 
 impl Item for Constant {
